"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@serverless-cd/core");
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
class Deploy {
    constructor(props, logger) {
        this.logger = (logger || console);
        this.props = props;
    }
    run() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const { resource, deployFile, deployArgs, envName, debugMode, workspace } = this.props;
            const cmd = resource ? `s ${resource} deploy` : 's deploy';
            let args = ['--use-local', '--assume-yes', '--skip-push'];
            if (envName) {
                args.push(`--env ${envName}`);
            }
            if (deployFile) {
                const manifest = path_1.default.resolve(workspace, deployFile);
                if (!core_1.fs.existsSync(manifest)) {
                    throw new Error(`The deploy manifest [${manifest}] does not exist`);
                }
                args.push(`-t ${deployFile}`);
            }
            if (debugMode) {
                args.push('--debug');
            }
            if (Array.isArray(deployArgs)) {
                args = args.concat(deployArgs);
            }
            this.logger.info(`Execute command: ${cmd} ${args.join(' ')}\n\n`);
            try {
                const subprocess = (0, execa_1.default)(cmd, args, {
                    shell: true,
                    stripFinalNewline: false,
                    cwd: workspace,
                });
                (_a = subprocess.stdout) === null || _a === void 0 ? void 0 : _a.pipe(process.stdout);
                yield subprocess;
            }
            catch (e) {
                throw new Error(core_1.lodash.get(e, 'originalMessage'));
            }
        });
    }
}
exports.default = Deploy;
//# sourceMappingURL=deploy.js.map